module display(
// connections to the DAC
VGA_OUT_PIXEL_CLOCK_P,
VGA_COMP_SYNCH_N,
VGA_OUT_BLANK_N,
VGA_HSYNCH_N,
VGA_VSYNCH_N,
VGA_OUT_RED_P,
VGA_OUT_GREEN_P,
VGA_OUT_BLUE_P,

// connections to the ZBT RAM
MEMORY_CLK_P,
MEMORY_CLKEN_N,
MEMORY_WEN_N,
MEMORY_WENA_N,
MEMORY_WENB_N,
MEMORY_WENC_N,
MEMORY_WEND_N,
MEMORY_ADV_LD_N,
MEMORY_OEN_N,
MEMORY_CEN_N,
MEMORY_ADDR_P,
MEMORY_DATA_A_P,
MEMORY_DATA_B_P,
MEMORY_DATA_C_P,
MEMORY_DATA_D_P,

pixel_clock,
reset,
);

output 		VGA_OUT_PIXEL_CLOCK_P;	// pixel clock for the video DAC
output		VGA_COMP_SYNCH_N;	// composite sync for the video DAC
output 		VGA_OUT_BLANK_N;	// composite blanking for the video DAC
output 		VGA_HSYNCH_N;		// horizontal sync for the VGA output connector
output		VGA_VSYNCH_N;		// vertical sync for the VGA output connector
output [7:0] 	VGA_OUT_RED_P;		// RED DAC data
output [7:0] 	VGA_OUT_GREEN_P;	// GREEN DAC data
output [7:0] 	VGA_OUT_BLUE_P;		// BLUE DAC data

output [18:0]	MEMORY_ADDR_P;		// external memory address bus
output 		MEMORY_CLK_P;		// external memory clock
output 		MEMORY_CLKEN_N;		// external memory clock enable
output 		MEMORY_WEN_N;		// external memory read/write
output 		MEMORY_WENA_N;		// external memory write enable for byte A
output 		MEMORY_WENB_N;		// external memory write enable for byte B
output 		MEMORY_WENC_N;		// external memory write enable for byte C
output 		MEMORY_WEND_N;		// external memory write enable for byte D
output 		MEMORY_OEN_N;		// external memory output enable
output 		MEMORY_CEN_N;		// external memory chip enable
output 		MEMORY_ADV_LD_N;	// external memory load/advance
inout [7:0] 	MEMORY_DATA_A_P;	// external memory byte A bits [ 7: 0] BLUE DATA
inout [7:0] 	MEMORY_DATA_B_P;	// external memory byte B bits [15: 8] GREEN DATA
inout [7:0] 	MEMORY_DATA_C_P;	// external memory byte C bits [23:16] RED DATA
inout [7:0] 	MEMORY_DATA_D_P;	// external memory byte D bits [31:24] MISC DATA

input	 		pixel_clock	/* synthesis syn_noclockbuf = 1 */; // pixel clock input 
input			reset;		// reset

wire			VGA_OUT_PIXEL_CLOCK_P;
wire 			VGA_COMP_SYNCH_N;
wire			VGA_OUT_BLANK_N;
wire			VGA_HSYNCH_N;
wire			VGA_VSYNCH_N;
wire	[7:0]		VGA_OUT_RED_P; 
wire	[7:0]		VGA_OUT_GREEN_P; 
wire	[7:0]		VGA_OUT_BLUE_P;

wire  	[18:0]		MEMORY_ADDR_P;
wire	 		MEMORY_CLK_P;
wire	 	 	MEMORY_CLKEN_N;
wire	 		MEMORY_WEN_N;
wire	 	 	MEMORY_WENA_N;
wire	 	 	MEMORY_WENB_N;
wire	 	 	MEMORY_WENC_N;
wire	 	 	MEMORY_WEND_N;
wire	 	 	MEMORY_OEN_N;
wire	 	 	MEMORY_CEN_N;
wire	 	 	MEMORY_ADV_LD_N;
wire	[7:0] 		MEMORY_DATA_A_P;
wire	[7:0] 		MEMORY_DATA_B_P;
wire	[7:0] 		MEMORY_DATA_C_P;
wire	[7:0] 		MEMORY_DATA_D_P;

reg 	[18:0]		user_vga_addr;
reg 			user_vga_read;
reg 			user_vga_write;
reg 			user_vga_write_byte_a;
reg 			user_vga_write_byte_b;
reg 			user_vga_write_byte_c;
reg 			user_vga_write_byte_d;
reg 			user_vga_enable;
wire 	[31:0]		user_vga_read_data;
reg  	[31:0]		user_vga_write_data;
wire			user_access_ok;
reg			user_clock_enable;
reg 			user_load_vga_addr;

//address counter
reg 	[18:0]		address_count;

wire 			pixel_clock;
wire 			reset;

//Write certain RGB values into memory for certain address locations
always @ (posedge pixel_clock) begin
	
	//increment address while user_access_ok is HIGH
	if (user_access_ok) begin
		user_vga_addr <= address_count;
		address_count <= address_count + 1;
		end

	//reset address counter to zero once it reaches 640x480
	if (address_count == 19'h4B000) begin
		address_count <= 19'h00000;
		end

	//display blue
	if (address_count < 19'd256000) begin
		user_vga_write_data <= 32'h000000F0;
		end
		
	//display brown
	else begin
		user_vga_write_data <= 32'h00F00F00;
		end
	     	
	end

//Memory control signals
always @ (posedge pixel_clock) begin
	
	if (user_access_ok) begin
		user_vga_read <= 1'b0;
		user_vga_write <= 1'b1;
		user_vga_write_byte_a <= 1'b1;
		user_vga_write_byte_b <= 1'b1;
		user_vga_write_byte_c <= 1'b1;
		user_vga_write_byte_d <= 1'b0;
		user_vga_enable <= 1'b1;
		user_clock_enable <= 1'b1;
		user_load_vga_addr <= 1'b1;
		end

end


BM_MODE_SVGA_CTRL BM_MODE_SVGA_CTRL_inst(
// connections to the DAC
.VGA_OUT_PIXEL_CLOCK_P(VGA_OUT_PIXEL_CLOCK_P),
.VGA_COMP_SYNCH_N(VGA_COMP_SYNCH_N),
.VGA_OUT_BLANK_N(VGA_OUT_BLANK_N),
.VGA_HSYNCH_N(VGA_HSYNCH_N),
.VGA_VSYNCH_N(VGA_VSYNCH_N),
.VGA_OUT_RED_P(VGA_OUT_RED_P),
.VGA_OUT_GREEN_P(VGA_OUT_GREEN_P),
.VGA_OUT_BLUE_P(VGA_OUT_BLUE_P),

// connections to the ZBT RAM
.MEMORY_CLK_P(MEMORY_CLK_P),
.MEMORY_CLKEN_N(MEMORY_CLKEN_N),
.MEMORY_WEN_N(MEMORY_WEN_N),
.MEMORY_WENA_N(MEMORY_WENA_N),
.MEMORY_WENB_N(MEMORY_WENB_N),
.MEMORY_WENC_N(MEMORY_WENC_N),
.MEMORY_WEND_N(MEMORY_WEND_N),
.MEMORY_ADV_LD_N(MEMORY_ADV_LD_N),
.MEMORY_OEN_N(MEMORY_OEN_N),
.MEMORY_CEN_N(MEMORY_CEN_N),
.MEMORY_ADDR_P(MEMORY_ADDR_P),
.MEMORY_DATA_A_P(MEMORY_DATA_A_P),
.MEMORY_DATA_B_P(MEMORY_DATA_B_P),
.MEMORY_DATA_C_P(MEMORY_DATA_C_P),
.MEMORY_DATA_D_P(MEMORY_DATA_D_P),

// connections to the user interface
.user_vga_addr(user_vga_addr),
.user_vga_read(user_vga_read),
.user_vga_write(user_vga_write),
.user_vga_write_byte_a(user_vga_write_byte_a),
.user_vga_write_byte_b(user_vga_write_byte_b),
.user_vga_write_byte_c(user_vga_write_byte_c),
.user_vga_write_byte_d(user_vga_write_byte_d),
.user_vga_enable(user_vga_enable),
.user_vga_read_data(user_vga_read_data),
.user_vga_write_data(user_vga_write_data),
.user_access_ok(user_access_ok),
.user_clock_enable(user_clock_enable),
.user_load_vga_addr(user_load_vga_addr),
.pixel_clock(pixel_clock),
.reset(reset)
);

endmodule